Index: /issm/trunk-jpl/src/m/qmu/plot/plot_hist_norm.m
===================================================================
--- /issm/trunk-jpl/src/m/qmu/plot/plot_hist_norm.m	(revision 18480)
+++ /issm/trunk-jpl/src/m/qmu/plot/plot_hist_norm.m	(revision 18481)
@@ -44,5 +44,7 @@
 %    ymin2         (numeric, minimum of cdf y-axis)
 %    ymax2         (numeric, maximum of cdf y-axis)
 %    nrmplt        (char, 'line' or 'off' to change nrm plots from 'bar')
 %    cdfplt        (char, 'off' to turn off cdf line plots)
 %    cdfleg        (char, 'off' to turn off cdf legends)
@@ -174,5 +176,5 @@
 
 %  parameters
-
+LineWidth=1;
 while (iarg <= nargin-1)
     if ischar(varargin{iarg})
@@ -180,5 +182,6 @@
                 {'hmin','hmax','hnint',...
                  'ymin1','ymax1','ymin2','ymax2',...
-                 'nrmplt','EdgeColor','FaceColor','cdfplt','cdfleg','nrmleg','cmap','titleplt','xlabelplt','ylabelplt','FontSize'},...
+                 'nrmplt','EdgeColor','FaceColor','LineWidth','cdfplt',...
+				     'cdfleg','nrmleg','cmap','titleplt','xlabelplt','ylabelplt','FontSize'},...
                 'exact'))
             eval([varargin{iarg} '=varargin{iarg+1};']);
@@ -251,5 +254,7 @@
     hl1(1*ncol+1:2*ncol)=...
         line(edges(1:end-1),dhistc(1:end-1,1*ncol+1:2*ncol),...
-             'LineWidth',2);
+             'LineWidth',LineWidth);
+elseif strncmpi(nrmplt,'s',1)
+	 hl1=stairs(edges(1:end-1)-(hmax-hmin)/hnint/2,dhistc(1:end-1,1:ncol));
 elseif strncmpi(nrmplt,'off',3)
     hl1=bar (edges(1:end-1),dhistc(1:end-1,1:1*ncol));
@@ -269,6 +274,8 @@
 
 %set face and edge color
-for i=1:length(hl1)
-	set(hl1(i),'EdgeColor',EdgeColor,'FaceColor',FaceColor);
+if ~strncmpi(nrmplt,'s',1)
+	for i=1:length(hl1)
+		set(hl1(i),'EdgeColor',EdgeColor,'FaceColor',FaceColor,'LineWidth',LineWidth);
+	end
 end
 
@@ -282,19 +289,21 @@
 cmap=colormap;
 for i=1:length(hl1)
-    if (length(hl1) > 1)
-        imap=round((i-1)/(length(hl1)-1)*(size(cmap,1)-1))+1;
-    else
-        imap=1;
-    end
-    if     strcmpi(get(hl1(i),'Type'),'hggroup')
-        if ischar(get(hl1(i),'FaceColor')) && ...
-           strcmpi(get(hl1(i),'FaceColor'),'flat')
-            set(hl1(i),'FaceColor',cmap(imap,:))
-        else
-            set(hl1(i),'FaceColor',get(hl1(i),'FaceColor'))
-        end
-    elseif strcmpi(get(hl1(i),'Type'),'line')
-        set(hl1(i),'Color',cmap(imap,:))
-    end
+	if (length(hl1) > 1)
+		imap=round((i-1)/(length(hl1)-1)*(size(cmap,1)-1))+1;
+	else
+		imap=1;
+	end
+	if ~strncmpi(nrmplt,'s',1) && strcmpi(get(hl1(i),'Type'),'hggroup')
+		if ischar(get(hl1(i),'FaceColor')) && ...
+				strcmpi(get(hl1(i),'FaceColor'),'flat')
+			set(hl1(i),'FaceColor',cmap(imap,:))
+		else
+			set(hl1(i),'FaceColor',get(hl1(i),'FaceColor'))
+		end
+	elseif strcmpi(get(hl1(i),'Type'),'line')
+		set(hl1(i),'Color',cmap(imap,:))
+	elseif strncmpi(nrmplt,'s',1)
+		set(hl1(i),'Color',EdgeColor,'LineWidth',2)
+	end
 end
 
@@ -44,5 +44,7 @@
 %    ymin2         (numeric, minimum of cdf y-axis)
 %    ymax2         (numeric, maximum of cdf y-axis)
-%    nrmplt        (char, 'line' or 'off' to change nrm plots from 'bar')
+%    nrmplt        (char, pass 'l' or 'off' to change nrm plots 
+%                   from default of 'bar' or 'b' to 'line' instead, 
+%                   pass 's' to change nrm plot to 'stairs')                                                  
 %    cdfplt        (char, 'off' to turn off cdf line plots)
 %    cdfleg        (char, 'off' to turn off cdf legends)
